pub struct BroadPhase2Config {
pub strategy: BroadPhase2Strategy,
pub brute_force_threshold: usize,
pub max_cells_per_item: usize,
pub cell_size: SpatialCellSize2,
}Expand description
Options for 2D broad-phase collision detection.
Fields
strategy: BroadPhase2StrategyStrategy to use.
brute_force_threshold: usizeMaximum item count handled with brute force in auto mode.
max_cells_per_item: usizeMaximum cells a single item may span before auto mode uses sweep and prune.
cell_size: SpatialCellSize2Spatial hash grid cell size.
Implementations