pub struct SpatialHashGrid2 { /* private fields */ }Expand description
Reusable spatial hash grid for 2D broad-phase collision detection.
Implementations
Sourceimpl SpatialHashGrid2
impl SpatialHashGrid2
Sourcepub fn new(config: BroadPhase2Config) -> Result<Self>
pub fn new(config: BroadPhase2Config) -> Result<Self>
Creates a new value.
Sourcepub fn rebuild(&mut self, bounds: &[RectU32]) -> Result<()>
pub fn rebuild(&mut self, bounds: &[RectU32]) -> Result<()>
Rebuilds this grid for a single set of bounds.
Sourcepub fn candidate_pairs(&mut self) -> Result<&[CollisionPair]>
pub fn candidate_pairs(&mut self) -> Result<&[CollisionPair]>
Returns candidate pairs for the most recently rebuilt single set.
Sourcepub fn candidate_pairs_between(
&mut self,
left: &[RectU32],
right: &[RectU32],
) -> Result<&[CollisionPair]>
pub fn candidate_pairs_between( &mut self, left: &[RectU32], right: &[RectU32], ) -> Result<&[CollisionPair]>
Returns candidate pairs between two independent sets.
Sourcepub fn stats(&self) -> BroadPhaseStats
pub fn stats(&self) -> BroadPhaseStats
Returns stats.